==> v2.0.0.tar.gz: alfresco-content-app/projects/aca-shared/src/public-api.ts <==
/*!
 * @license
 * Alfresco Example Content Application
 *
 * Copyright (C) 2005 - 2020 Alfresco Software Limited
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail.  Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 */

export * from './lib/adf-extensions/extensions-data-loader.guard';
export * from './lib/components/page-layout/page-layout-content.component';
export * from './lib/components/page-layout/page-layout-error.component';
export * from './lib/components/page-layout/page-layout-header.component';
export * from './lib/components/page-layout/page-layout.component';
export * from './lib/components/page-layout/page-layout.module';
export * from './lib/components/locked-by/locked-by.component';
export * from './lib/components/locked-by/locked-by.module';
export * from './lib/components/tool-bar/shared-toolbar.module';
export * from './lib/components/info-drawer/shared-info-drawer.module';

export * from './lib/models/types';
export * from './lib/models/viewer.rules';

export * from './lib/routing/app.routes.strategy';
export * from './lib/routing/shared.guard';

export * from './lib/services/app.service';
export * from './lib/services/content-api.service';
export * from './lib/services/node-permission.service';
export * from './lib/services/app.extension.service';
export * from './lib/services/router.extension.service';

export * from './lib/components/generic-error/generic-error.component';
export * from './lib/components/generic-error/generic-error.module';

export * from './lib/directives/contextmenu/contextmenu.module';
export * from './lib/directives/shared.directives.module';

export * from './lib/utils/node.utils';

export * from './lib/shared.module';

==> v2.4.0.tar.gz: alfresco-content-app/projects/aca-shared/src/public-api.ts <==
/*!
 * @license
 * Alfresco Example Content Application
 *
 * Copyright (C) 2005 - 2020 Alfresco Software Limited
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail.  Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 */

export * from './lib/adf-extensions/extensions-data-loader.guard';
export * from './lib/components/page-layout/page-layout-content.component';
export * from './lib/components/page-layout/page-layout-error.component';
export * from './lib/components/page-layout/page-layout-header.component';
export * from './lib/components/page-layout/page-layout.component';
export * from './lib/components/page-layout/page-layout.module';
export * from './lib/components/locked-by/locked-by.component';
export * from './lib/components/locked-by/locked-by.module';
export * from './lib/components/generic-error/generic-error.component';
export * from './lib/components/generic-error/generic-error.module';
export * from './lib/components/tool-bar/shared-toolbar.module';
export * from './lib/components/tool-bar/toolbar-action/toolbar-action.component';
export * from './lib/components/tool-bar/toolbar-button/toolbar-button.component';
export * from './lib/components/tool-bar/toolbar-menu/toolbar-menu.component';
export * from './lib/components/tool-bar/toolbar-menu-item/toolbar-menu-item.component';
export * from './lib/components/info-drawer/info-drawer.component';
export * from './lib/components/info-drawer/shared-info-drawer.module';

export * from './lib/directives/contextmenu/contextmenu.directive';
export * from './lib/directives/contextmenu/contextmenu.module';
export * from './lib/directives/pagination.directive';
export * from './lib/directives/shared.directives.module';

export * from './lib/models/types';
export * from './lib/models/viewer.rules';

export * from './lib/routing/shared.guard';

export * from './lib/services/app.service';
export * from './lib/services/content-api.service';
export * from './lib/services/node-permission.service';
export * from './lib/services/app.extension.service';
export * from './lib/services/router.extension.service';
export * from './lib/services/app-hook.service';

export * from './lib/utils/node.utils';
export * from './lib/shared.module';
export * from './lib/testing/lib-testing-module';
